@@ -45,6 +45,192 @@ extern "C" {
  * @{
  */
 
+/** Attribute value for VAConfigAttribEncHEVCFeatures.
+ *
+ * This attribute decribes the supported features of an HEVC/H.265
+ * encoder configuration.
+ *
+ * All of the field values in this attribute are VA_FEATURE_* values,
+ * indicating support for the corresponding feature.
+ */
+typedef union VAConfigAttribValEncHEVCFeatures {
+    struct {
+        /** Separate colour planes.
+         *
+         * Allows setting separate_colour_plane_flag in the SPS.
+         */
+        uint32_t separate_colour_planes     : 2;
+        /** Scaling lists.
+         *
+         * Allows scaling_list() elements to be present in both the SPS
+         * and the PPS.  The decoded form of the scaling lists must also
+         * be supplied in a VAQMatrixBufferHEVC buffer when scaling lists
+         * are enabled.
+         */
+        uint32_t scaling_lists              : 2;
+        /** Asymmetric motion partitions.
+         *
+         * Allows setting amp_enabled_flag in the SPS.
+         */
+        uint32_t amp                        : 2;
+        /** Sample adaptive offset filter.
+         *
+         * Allows setting slice_sao_luma_flag and slice_sao_chroma_flag
+         * in slice headers.
+         */
+        uint32_t sao                        : 2;
+        /** PCM sample blocks.
+         *
+         * Allows setting pcm_enabled_flag in the SPS.  When enabled
+         * PCM parameters must be supplied with the sequence parameters,
+         * including block sizes which may be further constrained as
+         * noted in the VAConfigAttribEncHEVCBlockSizes attribute.
+         */
+        uint32_t pcm                        : 2;
+        /** Temporal motion vector Prediction.
+         *
+         * Allows setting slice_temporal_mvp_enabled_flag in slice
+         * headers.
+         */
+        uint32_t temporal_mvp               : 2;
+        /** Strong intra smoothing.
+         *
+         * Allows setting strong_intra_smoothing_enabled_flag in the SPS.
+         */
+        uint32_t strong_intra_smoothing     : 2;
+        /** Dependent slices.
+         *
+         * Allows setting dependent_slice_segment_flag in slice headers.
+         */
+        uint32_t dependent_slices           : 2;
+        /** Sign data hiding.
+         *
+         * Allows setting sign_data_hiding_enable_flag in the PPS.
+         */
+        uint32_t sign_data_hiding           : 2;
+        /** Constrained intra prediction.
+         *
+         * Allows setting constrained_intra_pred_flag in the PPS.
+         */
+        uint32_t constrained_intra_pred     : 2;
+        /** Transform skipping.
+         *
+         * Allows setting transform_skip_enabled_flag in the PPS.
+         */
+        uint32_t transform_skip             : 2;
+        /** QP delta within coding units.
+         *
+         * Allows setting cu_qp_delta_enabled_flag in the PPS.
+         */
+        uint32_t cu_qp_delta                : 2;
+        /** Weighted prediction.
+         *
+         * Allows setting weighted_pred_flag and weighted_bipred_flag in
+         * the PPS.  The pred_weight_table() data must be supplied with
+         * every slice header when weighted prediction is enabled.
+         */
+        uint32_t weighted_prediction        : 2;
+        /** Transform and quantisation bypass.
+         *
+         * Allows setting transquant_bypass_enabled_flag in the PPS.
+         */
+        uint32_t transquant_bypass          : 2;
+        /** Deblocking filter disable.
+         *
+         * Allows setting slice_deblocking_filter_disabled_flag.
+         */
+        uint32_t deblocking_filter_disable  : 2;
+        /* Reserved,should not be used, avoid conflict with VA_ATTRIB_NOT_SUPPORTED. */
+        uint32_t reserved                   : 2;
+    } bits;
+    uint32_t value;
+} VAConfigAttribValEncHEVCFeatures;
+
+/** Attribute value for VAConfigAttribEncHEVCBlockSizes.
+ *
+ * This attribute describes the supported coding tree and transform block
+ * sizes of an HEVC/H.265 encoder configuration
+ */
+typedef union VAConfigAttribValEncHEVCBlockSizes {
+    struct {
+        /** Largest supported size of coding tree blocks.
+         *
+         * CtbLog2SizeY must not be larger than this.
+         */
+        uint32_t log2_max_coding_tree_block_size_minus3    : 2;
+        /** Smallest supported size of coding tree blocks.
+         *
+         * CtbLog2SizeY must not be smaller than this.
+         *
+         * This may be the same as the maximum size, indicating that only
+         * one CTB size is supported.
+         */
+        uint32_t log2_min_coding_tree_block_size_minus3    : 2;
+
+        /** Smallest supported size of luma coding blocks.
+         *
+         * MinCbLog2SizeY must not be smaller than this.
+         */
+        uint32_t log2_min_luma_coding_block_size_minus3    : 2;
+
+        /** Largest supported size of luma transform blocks.
+         *
+         * MaxTbLog2SizeY must not be larger than this.
+         */
+        uint32_t log2_max_luma_transform_block_size_minus2 : 2;
+        /** Smallest supported size of luma transform blocks.
+         *
+         * MinTbLog2SizeY must not be smaller than this.
+         */
+        uint32_t log2_min_luma_transform_block_size_minus2 : 2;
+
+        /** Largest supported transform hierarchy depth in inter
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_inter must not be larger
+         * than this.
+         */
+        uint32_t max_max_transform_hierarchy_depth_inter   : 2;
+        /** Smallest supported transform hierarchy depth in inter
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_inter must not be smaller
+         * than this.
+         */
+        uint32_t min_max_transform_hierarchy_depth_inter   : 2;
+
+        /** Largest supported transform hierarchy depth in intra
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_intra must not be larger
+         * than this.
+         */
+        uint32_t max_max_transform_hierarchy_depth_intra   : 2;
+        /** Smallest supported transform hierarchy depth in intra
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_intra must not be smaller
+         * than this.
+         */
+        uint32_t min_max_transform_hierarchy_depth_intra   : 2;
+
+        /** Largest supported size of PCM coding blocks.
+         *
+         *  Log2MaxIpcmCbSizeY must not be larger than this.
+         */
+        uint32_t log2_max_pcm_coding_block_size_minus3     : 2;
+        /** Smallest supported size of PCM coding blocks.
+         *
+         *  Log2MinIpcmCbSizeY must not be smaller than this.
+         */
+        uint32_t log2_min_pcm_coding_block_size_minus3     : 2;
+
+        /** Reserved for future use. */
+        uint32_t reserved                                  : 10;
+    } bits;
+    uint32_t value;
+} VAConfigAttribValEncHEVCBlockSizes;
+
 /**
  * @name Picture flags
  *
@@ -492,7 +678,7 @@ typedef struct _VAEncPictureParameterBufferHEVC {
             /** \brief Corresponds to HEVC syntax element of the same name. */
             uint32_t    transform_skip_enabled_flag                    : 1;
             /** \brief Corresponds to HEVC syntax element of the same name. */
-            uint32_t    cu_qp_delta_enabled_flag	               : 1;
+            uint32_t    cu_qp_delta_enabled_flag                   : 1;
             /** \brief Corresponds to HEVC syntax element of the same name. */
             uint32_t    weighted_pred_flag                             : 1;
             /** \brief Corresponds to HEVC syntax element of the same name. */
@@ -675,7 +861,7 @@ typedef struct _VAEncSliceParameterBufferHEVC {
             /** \brief Corresponds to HEVC syntax element of the same name. */
             uint32_t    mvd_l1_zero_flag                               : 1;
             /** \brief Corresponds to HEVC syntax element of the same name. */
-            uint32_t    cabac_init_flag        	                    : 1;
+            uint32_t    cabac_init_flag                             : 1;
             /** \brief Corresponds to HEVC syntax element of the same name. */
             uint32_t    slice_deblocking_filter_disabled_flag          : 2;
             /** \brief Corresponds to HEVC syntax element of the same name. */
@@ -703,7 +889,7 @@ typedef struct _VAEncSliceParameterBufferHEVC {
     */
     uint32_t                pred_weight_table_bit_length;
     /** \brief Reserved bytes for future use, must be zero */
-    uint32_t                va_reserved[VA_PADDING_MEDIUM-2];
+    uint32_t                va_reserved[VA_PADDING_MEDIUM - 2];
     /**@}*/
 } VAEncSliceParameterBufferHEVC;
 
@@ -719,8 +905,7 @@ typedef struct _VAEncSliceParameterBufferHEVC {
  *
  * Matrix entries are in raster scan order which follows HEVC spec.
  */
-typedef struct _VAQMatrixBufferHEVC
-{
+typedef struct _VAQMatrixBufferHEVC {
     /**
      * \brief scaling lists,
      * corresponds to same HEVC spec syntax element
